[nautilus-sound-converter] Add support for 'audio/mp2' mime types
- From: Brian Pepple <bpepple src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [nautilus-sound-converter] Add support for 'audio/mp2' mime types
- Date: Thu, 1 Sep 2011 21:47:05 +0000 (UTC)
commit c1d87a9d6956eafa7b0674e40bad01d5dbab228f
Author: Brian Pepple <bpepple fedoraproject org>
Date: Thu Sep 1 17:48:33 2011 -0400
Add support for 'audio/mp2' mime types
NEWS | 7 +++++++
src/nsc-extension.c | 4 +++-
2 files changed, 10 insertions(+), 1 deletions(-)
---
diff --git a/NEWS b/NEWS
index 494a4dc..2b850fd 100644
--- a/NEWS
+++ b/NEWS
@@ -1,3 +1,10 @@
+NEW in 3.0.2. - " ":
+===============
+- Add support for 'audio/mp2' mime type. (#657940)
+
+Translations:
+- Added Russian translation (Yuri Myasoedov)
+
NEW in 3.0.1 - "Too Small To Fail":
===============
- Show text in progress bars.
diff --git a/src/nsc-extension.c b/src/nsc-extension.c
index d13f2d0..56dd022 100644
--- a/src/nsc-extension.c
+++ b/src/nsc-extension.c
@@ -76,10 +76,12 @@ file_is_sound (NautilusFileInfo *file_info)
if (nautilus_file_info_is_mime_type (file_info, mime_types[i]))
return TRUE;
/* Check for mp3 support */
if (nsc_gstreamer_supports_mp3 (&error)) {
if (nautilus_file_info_is_mime_type (file_info, "audio/mpeg"))
return TRUE;
+ else if (nautilus_file_info_is_mime_type (file_info, "audio/mp2"))
+ return TRUE;
} else {
g_error_free (error);
error = NULL;
@@ -76,10 +76,12 @@ file_is_sound (NautilusFileInfo *file_info)
if (nautilus_file_info_is_mime_type (file_info, mime_types[i]))
return TRUE;
- /* Check for mp3 support */
+ /* Check for mp3 & mp2 support */
if (nsc_gstreamer_supports_mp3 (&error)) {
if (nautilus_file_info_is_mime_type (file_info, "audio/mpeg"))
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]